dot-unbox_scalars: Recursively unbox scalar values in nested lists for JSON...

.unbox_scalarsR Documentation

Recursively unbox scalar values in nested lists for JSON serialization

Description

Recursively unbox scalar values in nested lists for JSON serialization

Usage

.unbox_scalars(x, keep_arrays = character(0))

Arguments

x

List or atomic value

Value

Same structure with scalars wrapped in jsonlite::unbox


sd2R documentation built on June 19, 2026, 9:08 a.m.