sd_list_models: List registered models

View source: R/model_manager.R

sd_list_modelsR Documentation

List registered models

Description

Returns a data frame of all models in ~/.sd2R/models.json, with a column indicating which are currently loaded in memory.

Usage

sd_list_models()

Value

Data frame with columns: id, model_type, loaded, diffusion_path


sd2R documentation built on March 30, 2026, 5:08 p.m.