View source: R/model_manager.R
| sd_list_models | R Documentation |
Returns a data frame of all models in ~/.sd2R/models.json,
with a column indicating which are currently loaded in memory.
sd_list_models()
Data frame with columns: id, model_type, loaded, diffusion_path
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.