sd_unload_model: Unload a model from memory

View source: R/model_manager.R

sd_unload_modelR Documentation

Unload a model from memory

Description

Removes the cached context for the given model id. The model remains in the registry and can be reloaded with sd_load_model.

Usage

sd_unload_model(id)

Arguments

id

Model identifier

Value

No return value, called for side effects.


sd2R documentation built on March 30, 2026, 5:08 p.m.