View source: R/model_manager.R
| sd_unload_model | R Documentation |
Removes the cached context for the given model id. The model remains
in the registry and can be reloaded with sd_load_model.
sd_unload_model(id)
id |
Model identifier |
No return value, called for side effects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.